@@ -341,6 +341,8 @@ class MonitorClient(AbstractClient):
     def DescribeAlarmHistories(self, request):
         """查询告警历史
 
+        请注意，**如果使用子用户进行告警历史的查询，只能查询到被授权项目下的告警历史**，或不区分项目的产品的告警历史。如何对子账户授予项目的权限，请参考 [访问管理-项目与标签](https://cloud.tencent.com/document/product/598/32738)。
+
         :param request: Request instance for DescribeAlarmHistories.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmHistoriesRequest`
         :rtype: :class:`tencentcloud.monitor.v20180724.models.DescribeAlarmHistoriesResponse`
@@ -563,7 +565,7 @@ class MonitorClient(AbstractClient):
 
 
     def DescribeBaseMetrics(self, request):
-        """获取基础指标详情
+        """获取基础指标属性
 
         :param request: Request instance for DescribeBaseMetrics.
         :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeBaseMetricsRequest`
@@ -844,6 +846,34 @@ class MonitorClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeStatisticData(self, request):
+        """根据维度条件查询监控数据
+
+        :param request: Request instance for DescribeStatisticData.
+        :type request: :class:`tencentcloud.monitor.v20180724.models.DescribeStatisticDataRequest`
+        :rtype: :class:`tencentcloud.monitor.v20180724.models.DescribeStatisticDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeStatisticData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeStatisticDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def GetMonitorData(self, request):
         """获取云产品的监控数据。传入产品的命名空间、对象维度描述和监控指标即可获得相应的监控数据。
         接口调用频率限制为：20次/秒，1200次/分钟。单请求最多可支持批量拉取10个实例的监控数据，单请求的数据点数限制为1440个。
@@ -903,7 +933,7 @@ class MonitorClient(AbstractClient):
 
 
     def ModifyAlarmPolicyCondition(self, request):
-        """编辑告警策略触发条件
+        """修改告警策略触发条件
 
         :param request: Request instance for ModifyAlarmPolicyCondition.
         :type request: :class:`tencentcloud.monitor.v20180724.models.ModifyAlarmPolicyConditionRequest`
